@@ -1,7 +1,7 @@
-"""Tinychain `State`s, such as `Map`, `Tuple`, and `Op`."""
+"""Tinychain `State`\s, such as `Map`, `Tuple`, and `Op`."""
 
 from . import reflect
-from .ref import OpRef
+from .ref import Ref, OpRef
 from .util import *
 
 
@@ -23,7 +23,11 @@ class State(object):
         reflect.gen_headers(self)
 
     def __json__(self):
-        return {str(uri(self)): [to_json(form_of(self))]}
+        form = form_of(self)
+        if isinstance(form, URI):
+            return to_json(form)
+        else:
+            return {str(uri(self)): [to_json(form)]}
 
     def __ref__(self, name):
         return self.__class__(URI(name))
@@ -32,12 +36,12 @@ class State(object):
         return f"{self.__class__.__name__}({form_of(self)})"
 
     def dtype(self):
-        """Return the native `Class` of this `State`."""
+        """Return the native :class:`Class` of this `State`."""
         return Class(OpRef.get(uri(self) + "/class"))
 
 
 class Map(State):
-    """A key-value map whose keys are `Id`s and whose values are `State`s."""
+    """A key-value map whose keys are `Id`\s and whose values are `State`\s."""
 
     __uri__ = uri(State) + "/map"
 
@@ -49,7 +53,7 @@ class Map(State):
 
 
 class Tuple(State):
-    """A tuple of `State`s."""
+    """A tuple of `State`\s."""
 
     __uri__ = uri(State) + "/tuple"
 
